rest

package
v0.0.0-...-c9413cb Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 9, 2016 License: MIT Imports: 7 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client struct {
	// contains filtered or unexported fields
}

Client is the http client that sends requests to the gluster API.

func NewClient

func NewClient(addr, base string) *Client

NewClient initializes a new client.

func (Client) CreateVolume

func (r Client) CreateVolume(name string, peers []string) error

CreateVolume creates a new volume with the given name in the cluster.

func (Client) StopVolume

func (r Client) StopVolume(name string) error

StopVolume stops the volume with the given name in the cluster.

func (Client) VolumeExist

func (r Client) VolumeExist(name string) (bool, error)

VolumeExist returns whether a volume exist in the cluster with a given name or not.

Jump to