Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client is the http client that sends requests to the gluster API.
func (Client) CreateVolume ¶
CreateVolume creates a new volume with the given name in the cluster.
func (Client) StopVolume ¶
StopVolume stops the volume with the given name in the cluster.
Click to show internal directories.
Click to hide internal directories.